@@ -44,7 +44,7 @@ use byteorder::{BigEndian, ByteOrder, ReadBytesExt};
 
 use digest::generic_array::GenericArray;
 use digest::Digest;
-use hmac::{Hmac, Mac};
+use hmac::{Hmac, Mac, NewMac};
 use ripemd160::Ripemd160;
 use sha2::{Sha256, Sha512};
 
@@ -124,28 +124,28 @@ impl BIP32Hasher for BIP32GrinHasher {
 		b"IamVoldemort".to_owned()
 	}
 	fn init_sha512(&mut self, seed: &[u8]) {
-		self.hmac_sha512 = HmacSha512::new_varkey(seed).expect("HMAC can take key of any size");
+		self.hmac_sha512 = HmacSha512::new_from_slice(seed).expect("HMAC can take key of any size");
 	}
 	fn append_sha512(&mut self, value: &[u8]) {
-		self.hmac_sha512.input(value);
+		self.hmac_sha512.update(value);
 	}
 	fn result_sha512(&mut self) -> [u8; 64] {
 		let mut result = [0; 64];
-		result.copy_from_slice(self.hmac_sha512.result().code().as_slice());
+		result.copy_from_slice(&self.hmac_sha512.to_owned().finalize().into_bytes());
 		result
 	}
 	fn sha_256(&self, input: &[u8]) -> [u8; 32] {
 		let mut sha2_res = [0; 32];
 		let mut sha2 = Sha256::new();
-		sha2.input(input);
-		sha2_res.copy_from_slice(sha2.result().as_slice());
+		sha2.update(input);
+		sha2_res.copy_from_slice(sha2.finalize().as_slice());
 		sha2_res
 	}
 	fn ripemd_160(&self, input: &[u8]) -> [u8; 20] {
 		let mut ripemd_res = [0; 20];
 		let mut ripemd = Ripemd160::new();
-		ripemd.input(input);
-		ripemd_res.copy_from_slice(ripemd.result().as_slice());
+		ripemd.update(input);
+		ripemd_res.copy_from_slice(ripemd.finalize().as_slice());
 		ripemd_res
 	}
 }
@@ -701,28 +701,29 @@ mod tests {
 			b"Bitcoin seed".to_owned()
 		}
 		fn init_sha512(&mut self, seed: &[u8]) {
-			self.hmac_sha512 = HmacSha512::new_varkey(seed).expect("HMAC can take key of any size");
+			self.hmac_sha512 =
+				HmacSha512::new_from_slice(seed).expect("HMAC can take key of any size");
 		}
 		fn append_sha512(&mut self, value: &[u8]) {
-			self.hmac_sha512.input(value);
+			self.hmac_sha512.update(value);
 		}
 		fn result_sha512(&mut self) -> [u8; 64] {
 			let mut result = [0; 64];
-			result.copy_from_slice(self.hmac_sha512.result().code().as_slice());
+			result.copy_from_slice(&self.hmac_sha512.to_owned().finalize().into_bytes());
 			result
 		}
 		fn sha_256(&self, input: &[u8]) -> [u8; 32] {
 			let mut sha2_res = [0; 32];
 			let mut sha2 = Sha256::new();
-			sha2.input(input);
-			sha2_res.copy_from_slice(sha2.result().as_slice());
+			sha2.update(input);
+			sha2_res.copy_from_slice(sha2.finalize().as_slice());
 			sha2_res
 		}
 		fn ripemd_160(&self, input: &[u8]) -> [u8; 20] {
 			let mut ripemd_res = [0; 20];
 			let mut ripemd = Ripemd160::new();
-			ripemd.input(input);
-			ripemd_res.copy_from_slice(ripemd.result().as_slice());
+			ripemd.update(input);
+			ripemd_res.copy_from_slice(ripemd.finalize().as_slice());
 			ripemd_res
 		}
 	}
